/*------------------------------------------------------------------------------
    GALE. Fine-grained parallel Genetic Algorithms for Data Mining.
    Copyright (C) 2002  Xavier Llor <xllora@illigal.ge.uiuc.edu>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
------------------------------------------------------------------------------*/


package edu.uiuc.ge.illigal.gale.agents;


/** 
 * Defines a generic handle to Agent's Performance. It presents
 * the minimal set of needed data.
 *
 * @author  Xavier Llor&agrave; &lt;<a href="mailto:xllora@illigal.ge.uiuc.edu">xllora@illigal.ge.uiuc.edu</a>&gt;
 * @version 0.9alpha 
 * @since   0.9alpha 
 *
 */

public interface AgentPerformance
{
	//-------------------------------------------------------------------------

	/**
	 * Returns the confusion matrix.
	 *
	 * @return The confusion matrix
	 */
	public int [][] getConfusionMatrix ();

	//-------------------------------------------------------------------------

	/**
	 * Returns the total number of unclassified instances
	 *
	 * @return The number of unclassified instances processes
	 */
	public int getDontKnow ();

	//-------------------------------------------------------------------------

	/**
	 * Returns the total number of classified instances
	 *
	 * @return The number of instances processes
	 */
	public int getTotal ();

	//-------------------------------------------------------------------------

	/**
	 * Provides the overall classification performance information. 
	 * Computes the classification performance since the last reset of Agent.
	 *
	 * @return The classification performance
	 */
	public float getAccuracy ();

	//-------------------------------------------------------------------------

	/**
	 * Provides the overall classification performance information. 
	 * Computes the classification performance since the last reset of Agent.
	 *
	 * @return The classification performance
	 */
	public float getScaledAccuracy ();

	//-------------------------------------------------------------------------

	/**
	 * Updates the performance information. It needs the predicted class and
	 * the real class for the prediction.
	 *
	 * @param iCls The predicted class
	 * @param iReal The real class
	 */
	public void update ( int iCls, int iReal );

	//-------------------------------------------------------------------------

	/**
	 * Resets all the performance information contained.
	 */
	public void reset ();

	//-------------------------------------------------------------------------

	/**
	 * Compares if the performances are equal
	 *
	 * @param obj the performance to be compared with
	 * @return true if the performance are equal
	 */
	public boolean equals ( Object obj );

	//-------------------------------------------------------------------------

	/**
	 * Clones the current IncrementalLearning Performance object.
	 *
	 * @return The cloned object
	 * @throws CloneNotSupportedException The object could not be cloned
	 */
	public Object clone()
	throws CloneNotSupportedException;

	//-------------------------------------------------------------------------

	/**
	 * Converts the information into a string
	 *
	 * @return The stringfied information 
	 */
	public String toString();

	//-------------------------------------------------------------------------

}
