/*------------------------------------------------------------------------------
    GALE. Fine-grained parallel Genetic Algorithms for Data Mining.
    Copyright (C) 2002  Xavier Llor <xllora@illigal.ge.uiuc.edu>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
------------------------------------------------------------------------------*/


package edu.uiuc.ge.illigal.gale.data;

import java.util.Vector;

/**
 * Attribute class contains the information for an attribute of the data set.
 *
 * @author  Xavier Llor&agrave; &lt;<a href="mailto:xllora@illigal.ge.uiuc.edu">xllora@illigal.ge.uiuc.edu</a>&gt;
 * @version 0.9alpha
 * @since 0.9alpha
 */

public class AttributeSet
{
   //---------------------------------------------------------------------

	/** Set of attributes present in the data set */
	protected Vector vecAtts;

	//---------------------------------------------------------------------

   /** 
	 *  Builds an empty attribute set.
    */
   public AttributeSet ()
	{
		vecAtts = new Vector();
	}

   //---------------------------------------------------------------------

   /** 
	 *  Returns the attribute of the given index.
	 *
	 *  @param iPos the index of the attribute to retrieve
    *  @return the name
    */
   public Attribute attribute ( int iPos )
	{
		return (Attribute)vecAtts.elementAt(iPos);
	}

   //---------------------------------------------------------------------

   /** 
	 *  Adds an attribute to the attribute set.
	 *
    *  @param att the attribute to add
    */
   public void add ( Attribute att )
	{
		vecAtts.addElement(att);
	}

   //---------------------------------------------------------------------

   /** 
	 *  Returns the number of attributes kept in the set.
	 *
    *  @return the number of attributes
    */
   public int size()
	{
		return vecAtts.size();
	}

	//---------------------------------------------------------------------

	/** 
	 *  Returns the stringfied representation of attributes.
	 *
    *  @return the string
    */
   public String toString ()
	{
		String sRes = "";

		for ( int i=0, iMax=vecAtts.size() ; i<iMax ; i++ )
			sRes += vecAtts.elementAt(i)+"\n";

		return sRes;
	}


   //---------------------------------------------------------------------

	

}
