/*------------------------------------------------------------------------------
    GALE. Fine-grained parallel Genetic Algorithms for Data Mining.
    Copyright (C) 2002  Xavier Llor <xllora@illigal.ge.uiuc.edu>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
------------------------------------------------------------------------------*/


package edu.uiuc.ge.illigal.gale.data;

import edu.uiuc.ge.illigal.gale.config.GALEConfiguration;

import java.util.Vector;
import java.util.Date;

/**
 * This class implements a instance set that can be constructed and
 * updated from a control outside the class.
 *
 * @author  Xavier Llor&agrave; &lt;<a href="mailto:xllora@illigal.ge.uiuc.edu">xllora@illigal.ge.uiuc.edu</a>&gt;
 * @version 0.9alpha
 * @since 0.9alpha
 */

public class ConstructiveInstanceSet 
extends InstanceSet
{
   //---------------------------------------------------------------------

	/** GALE environment configuration object */
	protected GALEConfiguration galeCnf;

   //---------------------------------------------------------------------
	
	/**
    * Builds an initializes the data structures for the object.
	 *
    * @param size the number of instances that are going to be kept inside 
	 *             the object
    * @param name the relation name
    * @param gale the GALE environment configuration object
    * @param att the attribute set definition
	 */
	public ConstructiveInstanceSet ( int size, String name, 
	                                 GALEConfiguration gale, AttributeSet att )
	{
		iSize       = 0;
		sRelation   = name;
		attSet      = att;
		galeCnf     = gale;
		fsInstances = new Instance[size];
	}

   //---------------------------------------------------------------------

	/**
	 * Adds the instance to the Instance set.
	 *
	 * @param ins the instance to add.
    */
   public void setInstance ( Instance ins )
   {
		int i = 0;

		for ( ; fsInstances[i]!=null ; i++ );

		fsInstances[i] = ins;
		iSize++;
   }

   //---------------------------------------------------------------------

   // InstanceSet implementation
   public String toString ()
	{
		String sRes="";

		sRes += "%\n";
		sRes += "% GALE Environment instance set\n";
		sRes += "%\n";
		sRes += "% HoldOut file        : "+sRelation+".arff\n";
		sRes += "% Created at          : "+new Date()+"\n";
		sRes += "% Random seed used    : "+galeCnf.getSeed()+"\n";
		sRes += "% Number of Instances : "+iSize+"\n";
		sRes += "%\n\n";

		sRes += "@RELATION "+sRelation+"\n\n";
		sRes += attSet+"\n";

		sRes += "@DATA\n";

     	for ( int i=0 ; i<iSize ; i++ ) {
        sRes += fsInstances[i].toString()+"\n";
		}

     	return sRes;
	}

   //---------------------------------------------------------------------

}
