/*------------------------------------------------------------------------------
    GALE. Fine-grained parallel Genetic Algorithms for Data Mining.
    Copyright (C) 2002  Xavier Llor <xllora@illigal.ge.uiuc.edu>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
------------------------------------------------------------------------------*/


package edu.uiuc.ge.illigal.gale.data;

import java.util.Vector;

/**
 * This <strong>abstract</strong> class contains the set of instances available 
 * for a given problem. It is designed to contain real-valued instances.
 *
 * @author  Xavier Llor&agrave; &lt;<a href="mailto:xllora@illigal.ge.uiuc.edu">xllora@illigal.ge.uiuc.edu</a>&gt;
 * @version 0.9alpha
 * @since 0.9alpha
 */

public abstract class InstanceSet 
implements OrderedSet
{
   //---------------------------------------------------------------------

   /** Number of Instances present in the InstanceSet */
   protected int iSize;

   /** Contains the Instances of the InstanceSet */
   protected Instance [] fsInstances;

	/** Relation name */
	protected String sRelation;

	/** Class tags */
	protected AttributeSet attSet;

   //---------------------------------------------------------------------

	// OrderedSet implementation
   public Instance getInstance ( int iPos )
   {
        return fsInstances[iPos];
   }

   //---------------------------------------------------------------------

	// OrderedSet implementation
   public int getSize ()
   {
        return iSize;
   }

   //---------------------------------------------------------------------

	/** Returns the attribute set.
	 *
	 * @return the attribute set for the given relation
	 */
	public AttributeSet attributeSet()
	{
		return attSet;
	}

   //---------------------------------------------------------------------

	/** Returns the relation name.
	 *
	 * @return the relation name
	 */
	public String getRelationName ()
	{
		return sRelation;
	}

   //---------------------------------------------------------------------

   /** Converts the InstanceSet into a string readable format. It must be
    *   implemented for all subclasses
	 *
    *  @return The Instance information in a String format
    */
   public abstract String toString ();

   //---------------------------------------------------------------------

}
