/*------------------------------------------------------------------------------
    GALE. Fine-grained parallel Genetic Algorithms for Data Mining.
    Copyright (C) 2002  Xavier Llor <xllora@illigal.ge.uiuc.edu>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
------------------------------------------------------------------------------*/


package edu.uiuc.ge.illigal.gale.io;

import java.io.*;

/** 
 * Defines a simple IO factory with multiple channels.
 *
 * @author  Xavier Llor&agrave; &lt;<a href="mailto:xllora@illigal.ge.uiuc.edu">xllora@illigal.ge.uiuc.edu</a>&gt;
 * @version 0.9alpha 
 * @since   0.9alpha 
 *
 */

public interface IOFactory
{
	//-------------------------------------------------------------------------

	/**
	 * Opens a new IO channel.
	 *
	 * @param sName The channel name
	 * @param sURL The channel URL
	 * @return The channel descriptor
	 * @throws IOFactoryException The channel could not be opened
	 */
	public int openChannel ( String sName, String sURL )
	throws IOFactoryException;

	//-------------------------------------------------------------------------
	
	/**
	 * Closes an IO channel.
	 *
	 * @param iDesc The channel descriptor
	 * @throws IOFactoryException The channel could not be closed
	 */
	public void closeChannel ( int iDesc )
	throws IOFactoryException;

	//-------------------------------------------------------------------------
	
	/**
	 * Closes an IO channel.
	 *
	 * @param sName The channel name
	 * @throws IOFactoryException The channel could not be closed
	 */
	public void closeChannel ( String sName )
	throws IOFactoryException;


	//-------------------------------------------------------------------------
	
	/**
	 * Closes all IO channels.
	 *
	 * @throws IOFactoryException The channel could not be closed
	 */
	public void closeAllChannels ()
	throws IOFactoryException;

	//-------------------------------------------------------------------------

	/**
	 * Pushes the information into the given channel.
	 *
	 * @param iDesc The channel descriptor
	 * @param obj The object to be pushed
	 * @throws IOFactoryException The failure in channel
	 */
	public void push ( int iDesc, Object obj )
	throws IOFactoryException;

	//-------------------------------------------------------------------------

	/**
	 * Pushes the information into the given channel.
	 *
	 * @param sURL The channel name
	 * @param obj The object to be pushed
	 * @throws IOFactoryException The failure in channel
	 */
	public void push ( String sName, Object obj )
	throws IOFactoryException;

	//-------------------------------------------------------------------------

}

